pytilities.event.restricteddispatcher.RestrictedDispatcher

Package pytilities :: Package event :: Module restricteddispatcher :: Class RestrictedDispatcher |
[hide private]
[frames] | no frames]

# Class RestrictedDispatcher

source code

    object --+
             |
            RestrictedDispatcher

Dispatcher wrapper that filters the list of supported events.

Check Dispatcher for the documentation of the methods that are left undocumented here.

Instance Methods | [hide private]
__init__(self, dispatcher, allow=None, disallow=None) Construct a restricted dispatcher. | source code
add_handler(self, event_name, handler, owner=None) | source code
remove_handlers(self, event_name=None, owner=None) | source code
remove_handler(self, event_name, handler, owner=None) | source code
dispatch(self, event_name, *args, **keyword_args) | source code
event(self, event_name, owner=None) | source code
has_event(self, event_name) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
| __complement True, if allowed_events contains the complement of allowed events

Properties | [hide private]
| events
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, dispatcher, allow=None, disallow=None) (Constructor) | source code
Construct a restricted dispatcher. `disallow` and `allow` are mutually exclusive. Parameters: dispatcher :: Dispatcher the dispatcher to wrap around allow :: iter(string...): events that are allowed through disallow :: iter(string...) events that are hidden/blocked Overrides: object.__init__

Property Details | [hide private]

### events Get Method: unreachable.events(self)